@@ -41,10 +41,10 @@ KapmanMainWindow::KapmanMainWindow() {
 	KStandardGameAction::quit(this, SLOT(close()), actionCollection());
     	KAction* soundAction = new KToggleAction(i18n("&Play sounds"), this);
 	soundAction->setChecked(Settings::sounds());
-	actionCollection()->addAction("sounds", soundAction);
+	actionCollection()->addAction( QLatin1String( "sounds" ), soundAction);
 	connect(soundAction, SIGNAL(triggered(bool)), this, SLOT(setSoundsEnabled(bool)));
     	KAction* levelAction = new KAction(i18n("&Change level"), this);
-	actionCollection()->addAction("level", levelAction);
+	actionCollection()->addAction( QLatin1String( "level" ), levelAction);
 	connect(levelAction, SIGNAL(triggered(bool)), this, SLOT(changeLevel()));
 	// Add a statusbar to show level,score,lives information
 	m_statusBar = statusBar();
@@ -73,29 +73,24 @@ KapmanMainWindow::~KapmanMainWindow() {
 }
 
 void KapmanMainWindow::initGame() {
-	// If a Game instance already exists
-	if (m_game) {
-		// Delete the Game instance
-		delete m_game;
-	}
 	// Create a new Game instance
+	delete m_game;
 	m_game = new Game(KGameDifficulty::level());
 	connect(m_game, SIGNAL(gameOver(bool)), this, SLOT(newGame(bool)));		// TODO Remove the useless bool parameter from gameOver()
-	connect(m_game, SIGNAL( levelChanged( unsigned int ) ), this, SLOT( displayLevel( unsigned int ) ));
-	connect(m_game, SIGNAL( scoreChanged( unsigned int ) ), this, SLOT( displayScore( unsigned int ) ));
-	connect(m_game, SIGNAL( livesChanged( unsigned int ) ), this, SLOT( displayLives( unsigned int ) ));
+	connect(m_game, SIGNAL(levelChanged(uint)), this, SLOT(displayLevel(uint)));
+	connect(m_game, SIGNAL(scoreChanged(uint)), this, SLOT(displayScore(uint)));
+	connect(m_game, SIGNAL(livesChanged(uint)), this, SLOT(displayLives(uint)));
 	
 	
-	// If a GameView instance already exists
-	if (m_view) {
-		// Delete the GameView instance
-		delete m_view;
-	}
 	// Create a new GameView instance
+	delete m_view;
 	m_view = new GameView(m_game);
 	m_view->setBackgroundBrush(Qt::black);
 	setCentralWidget(m_view);
 	m_view->setFocus();
+	// For some reason, calling setFocus() immediately won't work after the
+	// score dialog has been shown, so do it again after an eventloop run.
+	QTimer::singleShot(0, m_view, SLOT(setFocus()));
 }
 
 
@@ -167,7 +162,8 @@ void KapmanMainWindow::showSettings() {
 	}
 	KConfigDialog* settingsDialog = new KConfigDialog(this, "settings", Settings::self());
 	settingsDialog->addPage(new KGameThemeSelector(settingsDialog, Settings::self(), KGameThemeSelector::NewStuffDisableDownload), i18n("Theme"), "kapman");
-	connect(settingsDialog, SIGNAL(settingsChanged(const QString&)), this, SLOT(loadSettings()));
+	settingsDialog->setFaceType(KConfigDialog::Plain); //only one page -> no page selection necessary
+	connect(settingsDialog, SIGNAL(settingsChanged(QString)), this, SLOT(loadSettings()));
 	settingsDialog->show();
 }
 
