@@ -361,7 +361,7 @@ bool Game::generateMove(const Player &player, bool undoable)
     if (!isRunning()) {
         return false;
     }
-
+    bool boardChange = false;
     const Player *tmp = &player;
     if (!tmp->isValid()) {
         //kDebug() << "Invalid player argument, using current player!";
@@ -420,7 +420,7 @@ bool Game::generateMove(const Player &player, bool undoable)
             } else {
                 undoStr = i18nc("%1 response from Go engine", "Black %1", m_response);
             }
-            emit boardChanged();
+            boardChange = true;
         }
 
         if (undoable) {
@@ -432,6 +432,9 @@ bool Game::generateMove(const Player &player, bool undoable)
         } else {
             setCurrentPlayer(m_whitePlayer);
         }
+        if (boardChange) {
+            emit boardChanged();
+        }
         return true;
     } else {
         return false;
@@ -750,6 +753,11 @@ bool Game::waitResponse(bool nonBlocking)
     return tmp != '?';                          // '?' Means the game didn't understand the query
 }
 
+void Game::gameSetup()
+{
+    emit boardInitialized();
+}
+    
 void Game::readyRead()
 {
     m_waitAndProcessEvents = false;
